pub enum AsyncRunError {
Io(Error),
Join(JoinError),
}Available on crate features
async and crossterm only.Expand description
Error returned when an asynchronous run loop is joined.
Variants
Io(Error)
The render loop returned an I/O error.
Join(JoinError)
Tokio reported task cancellation or a panic from the render loop.