Module halfblock

Module halfblock 

Half-block image rendering for terminals with truecolor support.

Uses (upper half block) with foreground/background colors to render two vertical pixels per terminal cell, achieving 2x vertical resolution.

Structs

HalfBlockImage
A terminal-renderable image stored as a grid of Color values.