CalDate

Struct CalDate 

pub struct CalDate {
    pub year: i32,
    pub month: u32,
    pub day: u32,
}
An absolute calendar date (year, month 1–12, day 1–31).

Used by CalendarState to represent range endpoints that can span month and year boundaries (a selected_day alone is scoped to the currently displayed month). Available since 0.21.0.

Example

use slt::CalDate;

let d = CalDate { year: 2024, month: 12, day: 31 };
assert_eq!((d.year, d.month, d.day), (2024, 12, 31));

Fields

year: i32

Calendar year.

month: u32

Month of year, 112.

day: u32

Day of month, 131.