#[non_exhaustive]pub enum ColorParseError {
InvalidLength,
InvalidHexDigit,
Unknown,
}Expand description
Error returned when Color fails to parse from a string.
Produced by the std::str::FromStr implementation for Color.
Example
use slt::Color;
let err = "#zz0011".parse::<Color>().unwrap_err();
// Display renders a human-readable reason.
assert!(err.to_string().contains("non-hex digit"));Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidLength
The input had a hex form (#… or all hex-looking) but the wrong
number of digits (only 3 or 6 are accepted).
InvalidHexDigit
The input contained a character that is not a valid hex digit.
Unknown
The input did not match any known hex form or named color.